@@ -12,6 +12,8 @@ import tkMessageBox
 import g
 import main
 import action
+import re
+import item
 
 global listbox_array
 listbox_array = []
@@ -64,11 +66,11 @@ def rm_equip():
 	if (len(listbox_equip.curselection()) > 0):
 		try: item_num = map(int, listbox_equip.curselection())
 		except ValueError: pass
-		if g.equip[item_num[0]] != -1:
-			if -1 != g.take_inv_item(g.equip[item_num[0]]):
+		if item.equip[item_num[0]] != -1:
+			if -1 != item.take_inv_item(item.equip[item_num[0]]):
 				main.print_message("You take off your " +
-					g.item[g.equip[item_num[0]]][0])
-				g.equip[item_num[0]] = -1
+					item.item[item.equip[item_num[0]]].name)
+				item.equip[item_num[0]] = -1
 	refresh_inv()
 
 #takes an item from the inventory, and wears it.
@@ -85,17 +87,17 @@ def wear_item():
 		return 0
 
 	#put the equip slot into item_loc
-	item_loc = g.item[item_value][1]
+	item_loc = item.item[item_value].type
 
 	#if item is equipment
 	if item_loc < 6:
 		#trade the item and whatever's in the equip slot
-		temp = g.equip[item_loc]
-		g.equip[item_loc] = item_value
-		g.drop_inv_item(item_num[0])
-		g.take_inv_item(temp)
+		temp = item.equip[item_loc]
+		item.equip[item_loc] = item_value
+		item.drop_inv_item(item_num[0])
+		item.take_inv_item(temp)
 		main.print_message("You equip yourself with your " +
-			g.item[g.equip[item_loc]][0] + ".")
+			item.item[item.equip[item_loc]].name + ".")
 		refresh_inv()
 
 #drops an item from the inventory. Uses the
@@ -105,15 +107,41 @@ def drop_item():
 	try: item_num = map(int, listbox_inv.curselection())
 	except ValueError: pass
 	try:
-		item_to_delete = g.find_inv_item(listbox_array[item_num[0]])
+		item_to_delete = item.find_inv_item(listbox_array[item_num[0]])
 	except IndexError: return 0
 
 	#the inv[] location of the item is now in item_to_delete.
 	#Ask if the player really wants to drop it.
 
-	if inv_show_yesno("Drop your " + g.item[g.inv[item_to_delete]][0] + "?"):
-		main.print_message("You drop your " + g.item[g.inv[item_num[0]]][0])
-		g.drop_inv_item(item_num[0])
+	if inv_show_yesno("Drop your " +
+			item.item[item.inv[item_to_delete]].name + "?"):
+		main.print_message("You drop your " +
+			item.item[item.inv[item_num[0]]].name)
+
+		# add dropped item to map
+		g.maps[g.zgrid].additem(item.item[item.inv[item_to_delete]].name,
+			g.xgrid, g.ygrid)
+# 		dropped_tile = g.tiles[item.item[item.inv[item_num[0]]].picturename]
+# 		g.maps[g.zgrid].field[g.ygrid][g.xgrid].add_pix(dropped_tile)
+
+		# edit onload to include dropped item
+# 		real_name = item.item[item.inv[item_num[0]]].name
+# 		item_name = re.sub(" ", "_", real_name);
+# 		line = "if var dropped_" + item_name + " | pass | addpix " + \
+# 			item.item[item.inv[item_num[0]]].picturename
+# 		g.maps[g.zgrid].field[g.ygrid][g.xgrid].add_onload(line)
+
+		# edit actions to include finding related actions
+# 		actions1 = "if var got_dropped_" + item_name + " | end | pass"
+# 		actions2 = "if find \"" + real_name + "\" a | set got_dropped_" + \
+# 			item_name + " = 1 | end"
+# 		actions3 = "delpix " + item.item[item.inv[item_num[0]]].picturename
+# 		g.maps[g.zgrid].field[g.ygrid][g.xgrid].add_act(actions1)
+# 		g.maps[g.zgrid].field[g.ygrid][g.xgrid].add_act(actions2)
+# 		g.maps[g.zgrid].field[g.ygrid][g.xgrid].add_act(actions3)
+
+		#remove the item from inventory
+		item.drop_inv_item(item_num[0])
 
 	refresh_inv()
 
@@ -210,14 +238,14 @@ def use_item():
 	except IndexError: return 0
 
 	#put the equip slot into item_loc
-	item_loc = g.item[item_value][1]
+	item_loc = item.item[item_value].type
 
-	main.print_message("You use your " + g.item[item_value][0])
+	main.print_message("You use your " + item.item[item_value].name)
 	#if item is healing
 	if item_loc == 11:
 		#heal the player, delete the item
-		g.hp=g.hp + g.item[item_value][2]
-		g.drop_inv_item(item_num[0])
+		g.hp=g.hp + item.item[item_value].quality
+		item.drop_inv_item(item_num[0])
 		if g.hp >= g.maxhp: g.hp = g.maxhp
 
 	refresh_inv()
@@ -237,7 +265,7 @@ def refresh_buttons(event=0):
 		except ValueError: pass
 		try:
 			item_value = listbox_array[item_num[0]]
-			item_loc = g.item[item_value][1]
+			item_loc = item.item[item_value].type
 		except IndexError: item_loc = 50
 
 		if (item_loc <= 6):
@@ -253,7 +281,7 @@ def refresh_buttons(event=0):
 		except ValueError: pass
 		try:
 			item_value = listbox_array[item_num[0]]
-			item_loc = g.item[item_value][1]
+			item_loc = item.item[item_value].type
 		except IndexError: item_loc = 50
 
 		if (item_loc <= 6): canvas_buttons.create_image(use_height, 0,
@@ -290,35 +318,35 @@ def refresh_inv():
 	#clear and rebuild listbox_inv
 	listbox_inv.delete(0, END)
 	listbox_array[0:len(listbox_array)] = []
-	for i in g.inv:
+	for i in item.inv:
 		if i != -1:
 			listbox_array.append(i)
-			listbox_inv.insert(END, g.item[i][0])
+			listbox_inv.insert(END, item.item[i].name)
 
 	#rebuild the equipment display
 	listbox_equip.delete(0, END)
-	temp = g.item[g.equip[0]][0]
-	if g.equip[0] == -1: temp = ""
+	temp = item.item[item.equip[0]].name
+	if item.equip[0] == -1: temp = ""
 	listbox_equip.insert(END, "Weapon: " + temp)
 
-	temp = g.item[g.equip[1]][0]
-	if g.equip[1] == -1: temp = ""
+	temp = item.item[item.equip[1]].name
+	if item.equip[1] == -1: temp = ""
 	listbox_equip.insert(END, "Armor: " + temp)
 
-	temp = g.item[g.equip[2]][0]
-	if g.equip[2] == -1: temp = ""
+	temp = item.item[item.equip[2]].name
+	if item.equip[2] == -1: temp = ""
 	listbox_equip.insert(END, "Shield: " + temp)
 
-	temp = g.item[g.equip[3]][0]
-	if g.equip[3] == -1: temp = ""
+	temp = item.item[item.equip[3]].name
+	if item.equip[3] == -1: temp = ""
 	listbox_equip.insert(END, "Helmet: " + temp)
 
-	temp = g.item[g.equip[4]][0]
-	if g.equip[4] == -1: temp = ""
+	temp = item.item[item.equip[4]].name
+	if item.equip[4] == -1: temp = ""
 	listbox_equip.insert(END, "Gloves: " + temp)
 
-	temp = g.item[g.equip[5]][0]
-	if g.equip[5] == -1: temp = ""
+	temp = item.item[item.equip[5]].name
+	if item.equip[5] == -1: temp = ""
 	listbox_equip.insert(END, "Boots: " + temp)
 
 	#restore the position.
