@@ -13,6 +13,9 @@ from random import random
 #needed for dialog boxes
 import tkMessageBox
 
+#needed for benchmarking. Uncomment to use.
+#from time import clock
+
 #local imports.
 import g
 import inv
@@ -21,7 +24,7 @@ import shop
 import action
 
 #size, in tiles, of the main screen. While this is adjustable,
-#an odd number would work much better. (To keep the player centered.)
+#odd numbers would work much better. (To keep the player centered.)
 mapsizex = 19
 mapsizey = 13
 
@@ -31,6 +34,10 @@ width = 20
 status_box_height =6
 tilesize = 32
 
+#division is nasty. Only do it once.
+half_mapx = mapsizex/2
+half_mapy = mapsizey/2
+
 #used for yes/no dialog boxes.
 active_button = 0
 return_from_yesno = StringVar()
@@ -111,6 +118,12 @@ def activate_scripting(x, y, z):
 	temp_xgrid = x + g.xgrid
 	temp_ygrid = y + g.ygrid
 	temp_zgrid = z
+
+	for itemname in g.maps[g.zgrid].field[temp_ygrid][temp_xgrid].items:
+		if action.activate_line(x, y, z, "find \"" + itemname + "\" a"):
+			g.maps[g.zgrid].del_item(itemname, temp_xgrid, temp_ygrid)
+			refresh_tile(half_mapx+x, half_mapy+y)
+
 	#if there are no actions, leave immediately
 	if len(g.maps[temp_zgrid].field[y+g.ygrid][x+g.xgrid].actions) == 0: return
 
@@ -128,19 +141,24 @@ def activate_scripting(x, y, z):
 #redraws the main map. Call after moving.
 def refreshmap():
 	#redraw the tiles
-	half_mapx = mapsizex/2 #division is nasty. Only do it once.
-	half_mapy = mapsizey/2
-	canvas_map.delete(ALL)
+#	canvas_map.delete(ALL)
 	for x in range(mapsizex):
 		for y in range(mapsizey):
-			for picture in findtile(x-half_mapx, y-half_mapy):
-				canvas_map.create_image(x*g.tilesize, y*g.tilesize,
-					anchor=NW, image=picture,
-					tags=str(g.xgrid+x-half_mapx)+"."+str(g.ygrid+y-half_mapy))
+			refresh_tile(x, y)
 
 	refreshhero()
 	recalc_stats()
 
+#given x and y relative to the upper-left corner of the visible map,
+# refresh the given tile.
+def refresh_tile(x, y):
+	search_for = str(g.xgrid+x-half_mapx)+"."+ str(g.ygrid+y-half_mapy)
+	canvas_map.delete(search_for)
+	for picture in findtile(x-half_mapx, y-half_mapy):
+		canvas_map.create_image(x*g.tilesize, y*g.tilesize, anchor=NW,
+		image=picture, tags=str(g.xgrid+x-half_mapx)+"."+
+		str(g.ygrid+y-half_mapy))
+
 #refreshs the hero; faster than refreshing the whole map.
 def refreshhero():
 	canvas_map.delete("hero")
@@ -182,14 +200,14 @@ def recalc_stats():
 	g.adj_attack = int(g.attack)
 
 	#adjust attack and defense based on equipment.
-	if g.equip[0] != -1:
-		g.adj_attack = g.adj_attack + g.item[g.equip[0]][2]
+	if g.item.equip[0] != -1:
+		g.adj_attack = g.adj_attack + g.item.item[g.item.equip[0]].quality
 	attack.set(g.adj_attack)
 
 	g.adj_defense = int(g.defense)
 	for i in range(1, 6):
-		if g.equip[i] != -1:
-			g.adj_defense = g.adj_defense + g.item[g.equip[i]][2]
+		if g.item.equip[i] != -1:
+			g.adj_defense = g.adj_defense + g.item.item[g.item.equip[i]].quality
 	defense.set(g.adj_defense)
 	gold.set(g.gold)
 	exp.set(g.exp)
@@ -214,6 +232,9 @@ def findtile(x, y):
 		returnpix.append(g.maps[g.zgrid].field[y][x].pix)
 		for picture in g.maps[g.zgrid].field[y][x].addpix:
 			returnpix.append(picture)
+		for itemname in g.maps[g.zgrid].field[y][x].items:
+			returnpix.append(
+				g.tiles[g.item.item[g.item.finditem(itemname)].picturename])
 		return returnpix
 	except IndexError:
 		#If it fails, there is rock there.
@@ -235,7 +256,7 @@ def move_hero(x, y):
 		#check for either the main window not existing, or a current dialog
 		if window_main.state() != "normal" or action.has_dialog == 1:
 			return
-
+		#tempclock = clock()
 		#check for any objects of interest. Called before moving, in case
 		#the scripting changes the walkable status.
 		activate_scripting(x, y, g.zgrid)
@@ -254,6 +275,7 @@ def move_hero(x, y):
 				if already_refreshed == 1:
 					refreshhero()
 					already_refreshed = 0
+					#print clock() - tempclock
 					return
 
 				#quick refresh.
@@ -261,49 +283,21 @@ def move_hero(x, y):
 				canvas_map.move(ALL, -x*tilesize, -y*tilesize)
 
 				#Refreshes the new part.
-				half_mapx = mapsizex/2
-				half_mapy = mapsizey/2
 				refreshhero()
 				recalc_stats()
 				g.allow_move = 1
 				if y == -1:
 					for tilenum in range(mapsizex):
-						search_for = str(g.xgrid+tilenum-half_mapx)+"."+ \
-							str(g.ygrid-half_mapy)
-						if len(canvas_map.gettags(search_for)) == 1: continue
-						canvas_map.delete(search_for)
-						for picture in findtile(tilenum-half_mapx, -half_mapy):
-							canvas_map.create_image(tilenum*g.tilesize, 0,
-							anchor=NW, image=picture, tags=search_for)
+						refresh_tile(tilenum, 0)
 				if y ==  1:
 					for tilenum in range(mapsizex):
-						search_for = str(g.xgrid+ tilenum-half_mapx)+"."+ \
-							str(g.ygrid+half_mapy)
-						if len(canvas_map.gettags(search_for)) == 1: continue
-						canvas_map.delete(search_for)
-						for picture in findtile(tilenum-half_mapx, half_mapy):
-							canvas_map.create_image(tilenum*g.tilesize,
-							g.tilesize*(mapsizey-1), anchor=NW, image=picture,
-							tags=search_for)
+						refresh_tile(tilenum, mapsizey-1)
 				if x == -1:
 					for tilenum in range(mapsizey):
-						search_for = str(g.xgrid-half_mapx)+"."+ \
-							str(g.ygrid+tilenum-half_mapy)
-						if len(canvas_map.gettags(search_for)) == 1: continue
-						canvas_map.delete(search_for)
-						for picture in findtile(-half_mapx, tilenum-half_mapy):
-							canvas_map.create_image(0, tilenum*g.tilesize,
-							anchor=NW, image=picture, tags=search_for)
+						refresh_tile(0, tilenum)
 				if x ==  1:
 					for tilenum in range(mapsizey):
-						search_for = str(g.xgrid+half_mapx) +"."+ \
-							str(g.ygrid+tilenum-half_mapy)
-						if len(canvas_map.gettags(search_for)) == 1: continue
-						canvas_map.delete(search_for)
-						for picture in findtile(half_mapx, tilenum-half_mapy):
-							canvas_map.create_image(g.tilesize*(mapsizex-1),
-							tilenum*g.tilesize, anchor=NW, image=picture,
-							tags=search_for)
+						refresh_tile(mapsizex-1, tilenum)
 
 		else:
 			if y == -1: g.cur_hero = "people/hero_n.png"
@@ -313,6 +307,7 @@ def move_hero(x, y):
 			refreshhero()
 			recalc_stats()
 		g.allow_move = 1
+		#print clock() - tempclock
 	except TclError:
 		pass
 
